@@ -71,6 +71,9 @@ sub build_binaries {
     elsif($pack->{pack} =~ m/^(SDL_Pango)$/ && !check_prereqs_tools('pkg-config')) {
       print "SKIPPING package '" . $pack->{dirname} . "' (pkg-config needed)...\n";
     }
+    elsif($pack->{pack} =~ m/^(SDL_ttf)$/ && $^O eq 'cygwin') {
+      print "SKIPPING package '" . $pack->{dirname} . "' (we cant use libfreetype)...\n";
+    }
     else {
       print "BUILDING package '" . $pack->{dirname} . "'...\n";
       my $srcdir = catfile($build_src, $pack->{dirname});
@@ -172,10 +175,12 @@ sub _get_configure_cmd {
     $extra .= " --disable-ld-version-script";
   }
 
-  if($^O eq 'solaris' && -d '/usr/ccs/bin') {
-    # otherwise we get "false cru build/libSDLmain.a build/SDL_dummy_main.o"
-    # see http://fixunix.com/ntp/245613-false-cru-libs-libopts-libopts_la-libopts-o.html#post661558
-    $extra_PATH = ':/usr/ccs/bin';
+  # otherwise we get "false cru build/libSDLmain.a build/SDL_dummy_main.o"
+  # see http://fixunix.com/ntp/245613-false-cru-libs-libopts-libopts_la-libopts-o.html#post661558
+  if ($^O eq 'solaris') {
+    for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
+      $extra_PATH .= ":$_" if -d $_;
+    }
   }
 
   ### This was intended as a fix for http://www.cpantesters.org/cpan/report/7064012
@@ -208,7 +213,7 @@ sub _get_configure_cmd {
 
 sub _get_make {
   my ($self) = @_;
-  my @try = ($Config{gmake}, 'gmake', 'make', $Config{make});
+  my @try = ('make', 'gmake', $Config{gmake}, $Config{make});
   my %tested;
   print "Gonna detect GNU make:\n";
   foreach my $name ( @try ) {
